# APPLEE: Automated Preprocessing Pipeline for Low-Electrode Encephalography

```
Authors: Luisa Maria Zapata S., Juliana Moreno Rada, Eduardo Montoya G., Santiago Gonzalez C., David F. Aguillón N., Carlos A. Tobón Q. ,John F. Ochoa G.
```


![image](https://github.com/user-attachments/assets/273d7022-637c-4f7a-a164-4bdd9f4812b8)
